package com.docus.server.collect.converter;

import com.docus.server.collect.entity.DownloadTask;
import com.docus.server.collect.enums.DownloadStateEnum;
import com.docus.server.collect.infrastructure.client.dto.ReportDownDto;
import com.docus.server.collect.infrastructure.client.dto.ReportDownPatientDto;
import com.docus.server.collect.infrastructure.client.dto.ReportDownScanFileDto;
import com.docus.server.collect.service.dto.ReportFileInfoDTO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import java.util.Collections;
import java.util.Date;
import java.util.List;

/**
 * @author 文件上报转换
 */
@Component
@Slf4j
public class FileReportConverter {


    /**
     * 转换病案文件上报信息，得到下载任务对象
     *
     * @param fileInfoDTO   病案文件上报信息
     * @param basicDataType 基础数据类型 0：普通病案 1：门急诊病案 2：省中医封存病案
     * @return 下载任务对象
     */
    public DownloadTask convertDownloadTask(ReportFileInfoDTO fileInfoDTO, Integer basicDataType) {
        Date currentTime = new Date();
        DownloadTask downloadTask = new DownloadTask();
        downloadTask.setPatientId(fileInfoDTO.getPatientId());
        downloadTask.setInpatientNo(fileInfoDTO.getInpatientNo());
        downloadTask.setAdmissions(fileInfoDTO.getAdmisstimes());
        downloadTask.setJzh(fileInfoDTO.getJzh());
        downloadTask.setLatestIp(fileInfoDTO.getIp());
        downloadTask.setLatestFileUrl(fileInfoDTO.getDownUrl());
        downloadTask.setLatestFileUrlType(fileInfoDTO.getDownWayEnum().value());
        downloadTask.setLatestFileTitle(fileInfoDTO.getFileTitle());
        downloadTask.setLatestZdAssortId(fileInfoDTO.getAssortId());
        downloadTask.setLatestReportTime(currentTime);
        downloadTask.setLatestDownloadStatus(DownloadStateEnum.WAIT.code());
        downloadTask.setCollectTaskId(fileInfoDTO.getTaskId());
        downloadTask.setSource(fileInfoDTO.getSysFlag());
        downloadTask.setFileSerialNum(fileInfoDTO.getSerialNum());
        downloadTask.setLatestReportUserName(fileInfoDTO.getUserName());
        downloadTask.setLatestReportUserFullName(fileInfoDTO.getReportUserFullName());
        downloadTask.setFileStorageFormat(1);
        downloadTask.setBasicDataType(basicDataType);
        return downloadTask;
    }
    /**
     * 下载任务转下载平台上报参数
     * @param downloadTask 下载任务
     * @return 下载平台上报参数
     */
    public ReportDownDto convertDownloadPlatformParam(DownloadTask downloadTask) {
        ReportDownPatientDto patient = convertDownloadPlatformPatientParam(downloadTask);
        List<ReportDownScanFileDto> scanFiles = Collections.singletonList(convertDownloadPlatformFileParam(downloadTask));
        ReportDownDto reportDownDto = new ReportDownDto();
        reportDownDto.setCollectorid(downloadTask.getSource());
        reportDownDto.setIp(downloadTask.getLatestIp());
        reportDownDto.setAssortid(downloadTask.getLatestZdAssortId());
        reportDownDto.setScanusercode(downloadTask.getLatestReportUserName());
        reportDownDto.setScanusername(downloadTask.getLatestReportUserFullName());
        reportDownDto.setPatient(patient);
        reportDownDto.setScanfiles(scanFiles);
        return reportDownDto;
    }
    /**
     * 下载任务转下载平台上报参数患者参数
     * @param downloadTask 下载任务
     * @return 下载平台上报参数患者参数
     */
    public ReportDownPatientDto convertDownloadPlatformPatientParam(DownloadTask downloadTask) {
        ReportDownPatientDto patientDto = new ReportDownPatientDto();
        patientDto.setPatientid(downloadTask.getPatientId());
        patientDto.setInpatientno(downloadTask.getInpatientNo());
        patientDto.setAdmisstimes(downloadTask.getAdmissions());
        patientDto.setJzh(downloadTask.getJzh());
        return patientDto;
    }

    /**
     * 下载任务转下载平台上报参数文件参数
     * @param downloadTask 下载任务
     * @return 下载平台上报参数文件参数
     */
    public ReportDownScanFileDto convertDownloadPlatformFileParam(DownloadTask downloadTask) {
        ReportDownScanFileDto scanFileDto = new ReportDownScanFileDto();
        scanFileDto.setTaskid(downloadTask.getCollectTaskId());
        scanFileDto.setFiletitle(downloadTask.getLatestFileTitle());
        scanFileDto.setFilesource(1);
        scanFileDto.setFilestoragetype(1);
        scanFileDto.setFiletype(downloadTask.getLatestFileUrlType());
        scanFileDto.setDownurl(downloadTask.getLatestFileUrl());
        scanFileDto.setSerialnum(downloadTask.getFileSerialNum());
        scanFileDto.setSortdate(null);
        scanFileDto.setCancel(0);
        scanFileDto.setAssortid(downloadTask.getLatestZdAssortId());
        scanFileDto.setFileStorageFormat(1);
        return scanFileDto;
    }
}
