package com.docus.server.collect.feign.api;

import com.docus.infrastructure.web.api.CommonResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestParam;

/**
 * 广东省中医采集api接口
 *
 * @author WYBDEV
 */
@Api(tags = "采集控制层")
@FeignClient(value = "docus-webservice-gdszy", contextId = "collect-gdszy")
public interface GdSzyCollectServiceApi {

    String PREFIX = "/collect/gdszy";

    @ApiOperation("LIS 检验报告采集,根据jzh")
    @ApiImplicitParams({
            @ApiImplicitParam(name ="empId",value = "你别看这个参数名是empId，其实传的和使用的是jzh，有偷懒的选手",required = true,paramType = "query",dataTypeClass = String.class)
    })
    @GetMapping(PREFIX + "/lisByJzh")
    CommonResult<String> lisSystemCollectByJzh(@RequestParam("empId") String empId);


    @ApiOperation("LIS 检验报告采集,根据封存id进行封存病案的采集")
    @ApiImplicitParams({
            @ApiImplicitParam(name ="sealId",value = "封存id",required = true,paramType = "query",dataTypeClass = String.class)
    })
    @GetMapping(PREFIX + "/lisBySealId")
    CommonResult<String> lisSystemCollectBySealId(@RequestParam("sealId") String sealId);

    @ApiOperation("LIS 检验报告采集，根据出院区间")
    @ApiImplicitParams({
            @ApiImplicitParam(name ="disDateStart",value = "出院时间 开始区间 yyyy-MM-dd",required = true,paramType = "query",dataTypeClass = String.class),
            @ApiImplicitParam(name ="disDateEnd",value = "出院时间 结束区间 yyyy-MM-dd",required = true,paramType = "query",dataTypeClass = String.class)
    })
    @GetMapping(PREFIX + "/lisByDisDate")
    CommonResult<String> lisSystemCollectByDisDate(@RequestParam("disDateStart") String disDateStart,@RequestParam("disDateEnd")String disDateEnd);

}
