package com.docus.server.collect.infrastructure.dao;

import com.docus.infrastructure.core.db.dao.IBaseDao;
import com.docus.server.collect.dto.TBasicQrDto;
import com.docus.server.collect.entity.DownloadTask;
import com.docus.server.collect.entity.TBasic;
import com.docus.server.collect.entity.TSeal;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * 下载任务表-数据访问接口
 *
 * @author wyb
 */
public interface DownloadTaskDao extends IBaseDao<DownloadTask> {
    /**
     * 根据患者信息，查询患者基础数据
     *
     * @param tBasic 患者基础信息
     * @return 患者基础数据
     */
    List<TBasic> getBasicInfo(TBasic tBasic);

    /**
     * 根据病案查询条件，查询病案数量
     * @param qrDto 查询条件
     * @return 病案数量
     */
    int countBasicInfo(@Param("dto") TBasicQrDto qrDto);

    /**
     * 根据条件，分页查询病案
     * @param qrDto 查询条件
     * @param offset 分页参数从第几条开始
     * @param size  每页显示条数
     * @return 病案基础信息
     */
    List<TBasic> pageBasicInfo(@Param("dto") TBasicQrDto qrDto,@Param("offset") int offset,@Param("size") int size);


    /**
     * 从下载任务表中获取下载任务id，来源，采文件唯一标识，和患者信息
     *
     * @param downloadTask 下载任务
     * @return 下载任务id（也是文件id）
     */
    Long getDownloadTaskIdFromDownloadTask(DownloadTask downloadTask);

    /**
     * 根据病案的来源，病案文件的唯一标识，从文件表得到文件下载任务id（也是文件id）
     *
     * @param patientId 病案主键
     * @param source    来源
     * @param serialNum 文件唯一标识
     * @return 下载任务id（也是文件id）
     */
    Long getDownloadTaskIdFromSanAssort(String patientId, String source, String serialNum);

    /**
     * 根据病案的来源，病案文件的唯一标识，从下载记录表得到文件下载任务id（也是文件id）
     *
     * @param patientId 病案主键
     * @param source    来源
     * @param serialNum 文件唯一标识
     * @return 下载任务id（也是文件id）
     */
    Long getDownloadTaskIdFromDownFile(String patientId, String source, String serialNum);

    /**
     * 根据封存条件查询封存信息
     * @date 2024/1/10 16:52
     * @author YongBin Wen
     * @param seal 封存条件
     * @return com.docus.server.collect.entity.TSeal
     */
    TSeal findSealByCondition(TSeal seal);

    boolean existIdFromSanAssort(Long fileId);

    boolean existIdFromDownfile(Long fileId);

    boolean existIdFromDownloadTask(Long fileId);
}
