package com.docus.server.collect.infrastructure.dao.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.docus.core.util.Func;
import com.docus.infrastructure.core.db.dao.impl.BaseDaoImpl;
import com.docus.server.collect.dto.TBasicQrDto;
import com.docus.server.collect.entity.DownloadTask;
import com.docus.server.collect.entity.TBasic;
import com.docus.server.collect.entity.TSeal;
import com.docus.server.collect.infrastructure.dao.DownloadTaskDao;
import com.docus.server.collect.infrastructure.mapper.DownloadTaskMapper;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 下载任务表-数据访问实现类
 *
 * @author wyb
 */
@Repository
public class DownloadTaskDaoImpl extends BaseDaoImpl<DownloadTaskMapper, DownloadTask> implements DownloadTaskDao {
    @Override
    public List<TBasic> getBasicInfo(TBasic basic) {
        return baseMapper.getBasicInfo(basic);
    }

    @Override
    public int countBasicInfo(TBasicQrDto qrDto) {
        return baseMapper.countBasicInfo(qrDto);
    }

    @Override
    public List<TBasic> pageBasicInfo(TBasicQrDto qrDto, int offset, int size) {
        return baseMapper.pageBasicInfo(qrDto,offset,size);
    }

    @Override
    public Long getDownloadTaskIdFromDownloadTask(DownloadTask downloadTask) {
        LambdaQueryWrapper<DownloadTask> wrapper = new LambdaQueryWrapper<>();
        wrapper.select(DownloadTask::getId);
        wrapper.eq(Func.isNotBlank(downloadTask.getPatientId()), DownloadTask::getPatientId, downloadTask.getPatientId());
        wrapper.eq(Func.isNotBlank(downloadTask.getJzh()), DownloadTask::getJzh, downloadTask.getJzh());
        wrapper.eq(Func.isNotBlank(downloadTask.getInpatientNo()), DownloadTask::getInpatientNo, downloadTask.getInpatientNo());
        wrapper.eq(Func.isNotEmpty(downloadTask.getAdmissions()), DownloadTask::getAdmissions, downloadTask.getAdmissions());
        wrapper.eq(DownloadTask::getFileSerialNum, downloadTask.getFileSerialNum());
        wrapper.eq(DownloadTask::getSource, downloadTask.getSource());
        List<DownloadTask> downloadTasks = baseMapper.selectList(wrapper);
        if (Func.isNotEmpty(downloadTasks) && downloadTasks.size() == 1) {
            return downloadTasks.get(0).getId();
        }
        return null;
    }

    @Override
    public Long getDownloadTaskIdFromSanAssort(String patientId, String source, String serialNum) {
        return baseMapper.getDownloadTaskIdFromSanAssort(patientId, source, serialNum);
    }

    @Override
    public Long getDownloadTaskIdFromDownFile(String patientId, String source, String serialNum) {
        return baseMapper.getDownloadTaskIdFromDownFile(patientId, source, serialNum);
    }

    @Override
    public TSeal findSealByCondition(TSeal seal) {
        return baseMapper.findSealByCondition(seal);
    }

    @Override
    public boolean existIdFromSanAssort(Long fileId) {
        Long id = baseMapper.getFileIdFromSanAssort(fileId);
        return id != null;
    }

    @Override
    public boolean existIdFromDownfile(Long fileId) {
        Long id = baseMapper.getFileIdFromDownfile(fileId);
        return id != null;
    }

    @Override
    public boolean existIdFromDownloadTask(Long fileId) {
        LambdaQueryWrapper<DownloadTask> wrapper = new LambdaQueryWrapper<>();
        wrapper.select(DownloadTask::getId);
        wrapper.eq(DownloadTask::getId, fileId);
        DownloadTask downloadTask = baseMapper.selectOne(wrapper);
        return downloadTask != null;
    }
}
