package com.docus.server.collect.infrastructure.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.docus.server.collect.dto.TBasicQrDto;
import com.docus.server.collect.entity.DownloadTask;
import com.docus.server.collect.entity.TBasic;
import com.docus.server.collect.entity.TSeal;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

@Mapper
public interface DownloadTaskMapper extends BaseMapper<DownloadTask> {
    /**
     * 根据患者信息获取基础病案信息 from    `docus_medicalrecord`.`t_basic`
     *
     * @param tBasic 患者基础信息
     * @return 病案基础信息
     */
    List<TBasic> getBasicInfo(@Param("basic") TBasic tBasic);

    /**
     * 根据病案查询条件，查询病案数量
     *
     * @param qrDto 查询条件
     * @return 病案数量
     */
    int countBasicInfo(@Param("dto") TBasicQrDto qrDto);

    /**
     * 根据条件，分页查询病案
     *
     * @param qrDto  查询条件
     * @param offset 分页参数从第几条开始
     * @param size   每页显示条数
     * @return 病案基础信息
     */
    List<TBasic> pageBasicInfo(@Param("dto") TBasicQrDto qrDto, @Param("offset") long offset, @Param("size") long size);

    /**
     * 根据病案的来源，病案文件的唯一标识，从文件表得到文件下载任务id（也是文件id）
     *
     * @param patientId 病案主键
     * @param source    来源
     * @param serialNum 文件唯一标识
     * @return 下载任务id（也是文件id）
     */
    Long getDownloadTaskIdFromSanAssort(@Param("patientId") String patientId, @Param("source") String source, @Param("serialNum") String serialNum);

    /**
     * 根据病案的来源，病案文件的唯一标识，从下载记录表得到文件下载任务id（也是文件id）
     *
     * @param patientId 病案主键
     * @param source    来源
     * @param serialNum 文件唯一标识
     * @return 下载任务id（也是文件id）
     */
    Long getDownloadTaskIdFromDownFile(@Param("patientId") String patientId, @Param("source") String source, @Param("serialNum") String serialNum);

    /**
     * 根据封存条件查询封存信息
     *
     * @param seal 封存条件
     * @return com.docus.server.collect.entity.TSeal
     * @date 2024/1/10 16:52
     * @author YongBin Wen
     */
    TSeal findSealByCondition(@Param("seal") TSeal seal);


    Long getFileIdFromDownfile(@Param("fileId") Long fileId);

    Long getFileIdFromSanAssort(@Param("fileId") Long fileId);
}
