package com.docus.server.collect.job;

import cn.hutool.core.collection.CollUtil;
import com.docus.core.util.Func;
import com.docus.server.collect.collector.LisSystemCollector;
import com.docus.server.collect.dto.TBasicQrDto;
import com.docus.server.collect.entity.TBasic;
import com.docus.server.collect.infrastructure.dao.DownloadTaskDao;
import com.xxl.job.core.context.XxlJobHelper;
import com.xxl.job.core.handler.annotation.XxlJob;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.util.Arrays;
import java.util.List;

/**
 * 检验报告采集
 * @author wyb
 */
@Component
@Slf4j
public class LisSystemCollectJob {

    @Resource
    private LisSystemCollector lisSystemCollector;
    @Resource
    private DownloadTaskDao downloadTaskDao;

    /**
     * 根据出院时间进行Lis报告采集
     */
    @XxlJob("LisSystemCollectOnDisDateJob")
    public void lisSystemCollectOnDisDateJob(){
        log.error(" =================================== 根据出院时间进行Lis报告采集（LisSystemCollectOnDisDateJob） START ===================================");
        String jobParam = XxlJobHelper.getJobParam();
        int[] defaultDisDays = {15};
        int[] finalDisDays;
        try {
            if (Func.isBlank(jobParam)) {
                finalDisDays = defaultDisDays;
            } else {
                String[] dayStrs = jobParam.split(",");
                int length = dayStrs.length;
                finalDisDays = new int[length];
                for (int i = 0; i < length; i++) {
                    finalDisDays[i] = Integer.parseInt(dayStrs[i]);
                }
            }
        } catch (Exception ex) {
            log.error("LIS系统采集，job参数解析错误,使用默认出院" + Arrays.toString(defaultDisDays) + "天采集！", ex);
            finalDisDays = defaultDisDays;
        }
        LocalDate nowLocalDate = LocalDate.now();
        for (int day : finalDisDays) {
            LocalDate localDate = nowLocalDate.plusDays(-day);
            String disDateStart=localDate+" 00:00:00";
            String disDateEnd=localDate+" 23:59:59";
            TBasicQrDto qrDto = new TBasicQrDto();
            qrDto.setDisDateStart(disDateStart);
            qrDto.setDisDateEnd(disDateEnd);
            // 直接查一万条
            List<TBasic> tBasics = downloadTaskDao.pageBasicInfo(qrDto, 0, 10000);
            if(CollUtil.isNotEmpty(tBasics)){
                for (TBasic basic : tBasics) {
                    lisSystemCollector.collect(basic);
                }
            }
            tBasics.clear();
        }

        log.error(" =================================== 根据出院时间进行Lis报告采集（LisSystemCollectOnDisDateJob） END ===================================");

    }

}
