package com.docus.server.collect.service.dto;

import com.docus.server.collect.enums.DownWayEnum;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;

/**
 * 上报的文件信息
 * 住院号,记账号,住院次数,患者病案主键 必须有一组组合能查出患者基础信息且唯一，不能多传参数，防止查不出来
 *
 * @author wyb
 */
@ApiModel("上报的文件信息对象")
@Data
public class ReportFileInfoDTO {

    /**
     * 住院号
     */
    @ApiModelProperty("住院号")
    private String inpatientNo;
    /**
     * 记账号/住院流水号
     */
    @ApiModelProperty("记账号/住院流水号")
    private String jzh;
    /**
     * 住院次数
     */
    @ApiModelProperty("住院次数")
    private Integer admisstimes;
    /**
     * 患者病案主键
     */
    @ApiModelProperty("患者病案主键")
    private String patientId;
    /**
     * 采集来源系统
     */
    @ApiModelProperty("采集来源系统")
    @NotBlank
    private String sysFlag;
    /**
     * 下载地址
     */
    @ApiModelProperty("下载地址")
    @NotBlank
    private String downUrl;

    /**
     * 下载地址
     */
    @ApiModelProperty("下载地址类型")
    @NotNull
    private DownWayEnum downWayEnum;

    /**
     * 文件名
     */
    @ApiModelProperty("文件名")
    @NotBlank
    private String fileTitle;
    /**
     * 采集流水号/文件唯一id
     */
    @ApiModelProperty("采集流水号/文件唯一id")
    @NotBlank
    private String serialNum;
    /**
     * 文件分类id
     */
    @ApiModelProperty("文件分类id")
    @NotBlank
    private String assortId;


    /**
     * 下载对应任务id ,接收处理
     */
    @ApiModelProperty("下载对应任务id ,接收处理")
    private Long taskId;

    /**
     * ip地址
     */
    @ApiModelProperty("ip地址")
    private String ip;

    /**
     * 用户工号
     */
    @ApiModelProperty("用户工号")
    private String userName;

    /**
     * 用户名
     */
    @ApiModelProperty("用户名")
    private String reportUserFullName;
}
