package com.docus.server.collect.service.impl;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.util.StrUtil;
import com.docus.core.util.Func;
import com.docus.infrastructure.redis.service.IdService;
import com.docus.infrastructure.web.api.CommonResult;
import com.docus.server.collect.converter.FileReportConverter;
import com.docus.server.collect.entity.DownloadTask;
import com.docus.server.collect.entity.TBasic;
import com.docus.server.collect.entity.TSeal;
import com.docus.server.collect.infrastructure.client.DownloadPlatformService;
import com.docus.server.collect.infrastructure.client.dto.ReportDownDto;
import com.docus.server.collect.infrastructure.dao.DownloadTaskDao;
import com.docus.server.collect.service.FileReportService;
import com.docus.server.collect.service.dto.ReportFileInfoDTO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.concurrent.ThreadPoolExecutor;

/**
 * 文件上报-实现
 *
 * @author wyb
 */
@Slf4j
@Service
public class FileReportServiceImpl implements FileReportService {
    @Autowired
    private DownloadPlatformService downloadPlatformService;
    @Autowired
    private DownloadTaskDao downloadTaskDao;
    @Autowired
    private FileReportConverter fileReportConverter;

    @Autowired
    private IdService idService;

    @Autowired
    private ThreadPoolExecutor threadPoolExecutor;

    @Override
    public void saveDownloadTaskAndReport(ReportFileInfoDTO fileInfoDTO) {
        TBasic basic = new TBasic(fileInfoDTO);
        // 查询基础数据，更新新的病案信息
        List<TBasic> tBasics = downloadTaskDao.getBasicInfo(basic);
        // 如果找到患者基础数据，并且刚好为1条
        if (CollUtil.isNotEmpty(tBasics) && tBasics.size() == 1) {
            TBasic tBasic = tBasics.get(0);
            fileInfoDTO.setPatientId(tBasic.getPatientId());
            fileInfoDTO.setInpatientNo(tBasic.getInpatientNo());
            fileInfoDTO.setAdmisstimes(tBasic.getAdmissTimes());
            fileInfoDTO.setJzh(tBasic.getJzh());
        }
        // 转换下载任务对象
        DownloadTask downloadTask = fileReportConverter.convertDownloadTask(fileInfoDTO, 0);
        // 为什么不保存呢，因为总出现文件id重复，所有文件id交给下载服务生成
        // 查询旧的下载任务id,更新/保存任务信息
//        Long downloadTaskId = Optional.ofNullable(getDownloadTaskId(downloadTask)).orElse(getNewFileId());
//        downloadTask.setId(downloadTaskId);
//        downloadTaskDao.saveOrUpdate(downloadTask);
        report(downloadTask);
    }

    @Override
    public void saveDownloadTaskAndSealReport(ReportFileInfoDTO fileInfoDTO) {
        TSeal sealCondition = new TSeal(fileInfoDTO);
        // 查询基础数据，更新新的病案信息
        TSeal seal = downloadTaskDao.findSealByCondition(sealCondition);
        // 如果找到患者基础数据，并且刚好为1条
        fileInfoDTO.setPatientId(seal.getPatientId());
        fileInfoDTO.setInpatientNo(seal.getInpatientNo());
        fileInfoDTO.setAdmisstimes(seal.getAdmissTimes());
        fileInfoDTO.setJzh(seal.getJzh());
        // 转换下载任务对象
        DownloadTask downloadTask = fileReportConverter.convertDownloadTask(fileInfoDTO, 2);
        // 为什么不保存呢，因为总出现文件id重复，所有文件id交给下载服务生成
        // 查询旧的下载任务id,更新/保存任务信息
//        Long downloadTaskId = Optional.ofNullable(getDownloadTaskId(downloadTask)).orElse(getNewFileId());
//        downloadTask.setId(downloadTaskId);
//        downloadTaskDao.saveOrUpdate(downloadTask);
        reportSeal(downloadTask);
    }

    /**
     * 获取一个新的文件id，从下载表，下载任务表，文件表判断，不存在三个表里的文件id
     */
    private Long getNewFileId() {
        Long fileId = idService.getDateSeq();

        while (true) {
            boolean existIdFromSanAssort = downloadTaskDao.existIdFromSanAssort(fileId);
            boolean existIdFromDownfile = downloadTaskDao.existIdFromDownfile(fileId);
            boolean existIdFromDownloadTask = downloadTaskDao.existIdFromDownloadTask(fileId);
            if (!existIdFromSanAssort && !existIdFromDownfile && !existIdFromDownloadTask) {
                return fileId;
            }
            fileId = fileId + 16;
        }
    }

    @Override
    public Long getDownloadTaskId(DownloadTask downloadTask) {
        String patientId = downloadTask.getPatientId();
        if (StrUtil.isNotBlank(patientId)) {
            String serialNum = downloadTask.getFileSerialNum();
            String source = downloadTask.getSource();
            // 从文件表获取
            Long downloadTaskId = downloadTaskDao.getDownloadTaskIdFromSanAssort(patientId, source, serialNum);
            if (Func.isNotEmpty(downloadTaskId)) {
                return downloadTaskId;
            }
            // 从下载记录表获取
            downloadTaskId = downloadTaskDao.getDownloadTaskIdFromDownFile(patientId, source, serialNum);
            if (Func.isNotEmpty(downloadTaskId)) {
                return downloadTaskId;
            }
        }
        // 从下载任务表获取，不考虑重复，重复那就是调研不清楚或者代码调用错误
        return downloadTaskDao.getDownloadTaskIdFromDownloadTask(downloadTask);
    }

    /**
     * 根据下载任务，上报到下载平台服务
     *
     * @param downloadTask 下载任务
     */
    private void report(DownloadTask downloadTask) {
            if (downloadTask.getBasicDataType().equals(0)) {
                ReportDownDto reportDownDto = fileReportConverter.convertDownloadPlatformParam(downloadTask);
                String paramJson = Func.toJson(reportDownDto);
                try {
                    log.info("基础病案上报文件，参数：{}", paramJson);
                    CommonResult result = downloadPlatformService.report(reportDownDto);
                    log.info("基础病案上报文件，返回结果：{}", Func.toJson(result));
                } catch (Exception ex) {
                    log.error("基础病案上报文件发生未知错误，参数：" + paramJson, ex);
                }
            }
    }

    /**
     * 根据下载任务，上报到下载平台服务
     *
     * @param downloadTask 下载任务
     */
    private void reportSeal(DownloadTask downloadTask) {
            if (downloadTask.getBasicDataType().equals(2)) {
                ReportDownDto reportDownDto = fileReportConverter.convertDownloadPlatformParam(downloadTask);
                String paramJson = Func.toJson(reportDownDto);
                try {
                    log.info("封存病案上报文件，参数：{}", paramJson);
                    CommonResult result = downloadPlatformService.sealReport(reportDownDto);
                    log.info("封存病案上报文件，返回结果：{}", Func.toJson(result));
                } catch (Exception ex) {
                    log.error("封存病案上报文件发生未知错误，参数：" + paramJson, ex);
                }
            }
    }
}
